@@ -6,5 +6,6 @@ Part of the three-tier V1.1 architecture with complete 4-pattern detailed functi
 """
 
 from .sites_client import SitesClient
+from . import models
 
-__all__ = ['SitesClient']
\ No newline at end of file
+__all__ = ['SitesClient', 'models']
\ No newline at end of file
